Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1385)

Unified Diff: runtime/vm/intrinsifier.cc

Issue 1133713006: Deprecate 'dart:profiler' and move functionality to 'dart:developer' (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/bootstrap.cc ('k') | runtime/vm/method_recognizer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/intrinsifier.cc
diff --git a/runtime/vm/intrinsifier.cc b/runtime/vm/intrinsifier.cc
index 37ff3d75be8f064bcbedbb6b0e8e3bf8e37f87dc..71cf333c0ed8866b6001cc54f3feada0b4c38101 100644
--- a/runtime/vm/intrinsifier.cc
+++ b/runtime/vm/intrinsifier.cc
@@ -84,10 +84,10 @@ void Intrinsifier::InitializeState() {
TYPED_DATA_LIB_INTRINSIC_LIST(SETUP_FUNCTION);
GRAPH_TYPED_DATA_INTRINSICS_LIST(SETUP_FUNCTION);
- // Setup all dart:profiler lib functions that can be intrinsified.
- lib = Library::ProfilerLibrary();
+ // Setup all dart:developer lib functions that can be intrinsified.
+ lib = Library::DeveloperLibrary();
ASSERT(!lib.IsNull());
- PROFILER_LIB_INTRINSIC_LIST(SETUP_FUNCTION);
+ DEVELOPER_LIB_INTRINSIC_LIST(SETUP_FUNCTION);
#undef SETUP_FUNCTION
}
« no previous file with comments | « runtime/vm/bootstrap.cc ('k') | runtime/vm/method_recognizer.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698